@@ -193,24 +193,10 @@ def step_up():
 def done():
     '''hides the turtle and waits until the resulting window is clicked'''
     __SingletonTurtle().hideturtle()
+    Screen().update()
     Screen().exitonclick()
 
 
-def home():
-    """
-    Move turtle to the origin - coordinates (0,0).
-
-    No arguments.
-
-    Move turtle to the origin - coordinates (0,0) and set its
-    heading to its start-orientation (which depends on mode).
-
-    Example (for a Turtle instance named turtle):
-    >>> turtle.home()
-    """
-    __SingletonTurtle().home()
-
-
 def goto(x: int, y: int = None, draw: bool = True):
     """Move turtle to an absolute position.
 
@@ -255,6 +241,24 @@ def goto(x: int, y: int = None, draw: bool = True):
         __SingletonTurtle().pendown()
 
 
+def home(draw: bool = True):
+    """
+    Move turtle to the origin - coordinates (0,0).
+
+    Arguments:
+    draw -- bool              True
+
+    Move turtle to the origin - coordinates (0,0) and set its
+    heading to its start-orientation (which depends on mode).
+
+    Example (for a Turtle instance named turtle):
+    >>> turtle.home()
+    """
+    if draw == False:
+        goto(0, 0, draw=False)
+    __SingletonTurtle().home()
+
+
 def pos() -> turtle.Vec2D:
     """Return the turtle's current location (x,y), as a Vec2D-vector.
 
@@ -464,20 +468,6 @@ def pencolor(*args):
     return __SingletonTurtle().pencolor(*args)
 
 
-def home():
-    """Move turtle to the origin - coordinates (0,0).
-
-    No arguments.
-
-    Move turtle to the origin - coordinates (0,0) and set its
-    heading to its start-orientation (which depends on mode).
-
-    Example (for a Turtle instance named turtle):
-    >>> turtle.home()
-    """
-    return __SingletonTurtle().home()
-
-
 def clear():
     """Delete all drawings and all turtles from the TurtleScreen.
 
@@ -693,7 +683,7 @@ def speed(speed=None):
     Example (for a Turtle instance named turtle):
     >>> turtle.speed(3)
     """
-    return __SingletonTurtle().speed()
+    return __SingletonTurtle().speed(speed)
 
 
 def showturtle():
@@ -723,6 +713,42 @@ def isvisible():
     return __SingletonTurtle().isvisible()
 
 
+def grid(xmin: int, xmax: int, ymin: int, ymax: int, tick: int, scale: int = 1):
+    '''draws a grid and draws the coordinate numbers
+    '''
+    if tkinter.TkVersion < 8.6:
+        raise "TkVersion must be >= 8.6"
+    old_pos = getturtle().pos()
+    old_pensize = getturtle().pensize()
+    pensize(1)
+    old_color = getturtle().color()
+    old_update_freq = Screen().tracer()
+    old_delay = Screen().delay()
+    Screen().tracer(0, 0)
+    pencolor('lightgray')
+    offset_x = len(str(max(xmax, xmin))) * 2
+    offset_y = len(str(max(ymax, ymin))) * 2
+    for xtick in range(scale * xmin, scale * xmax + 1, tick):
+        Screen().getcanvas().create_text(xtick * Screen().xscale + offset_x, -(scale * xmin - 2) *
+                                         Screen().yscale, text=xtick, fill="black", anchor="se", angle=90, font=("Arial", 8, "normal"))
+        Screen().update()
+        goto(xtick, scale * ymin, draw=False)
+        goto(xtick, scale * ymax, draw=True)
+
+    for ytick in range(scale * ymin, scale * ymax + 1, tick):
+        goto(scale * xmin, ytick - offset_y, draw=False)
+        pencolor('black')
+        write(ytick, align='right')
+        pencolor('lightgray')
+        goto(scale * xmin, ytick, draw=False)
+        goto(scale * xmax, ytick, draw=True)
+    Screen().update()
+    goto(*old_pos, draw=False)
+    pensize(old_pensize)
+    color(*old_color)
+    Screen().tracer(old_update_freq, old_delay)
+
+
 if __name__ == '__main__':
     forward(10)
     pencolor(0.2, 0.8, 0.55)
